# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding unique constraint on 'NewsletterSignup', fields ['confirmation_key']
        db.create_unique(u'aldryn_jobs_newslettersignup', ['confirmation_key'])


    def backwards(self, orm):
        # Removing unique constraint on 'NewsletterSignup', fields ['confirmation_key']
        db.delete_unique(u'aldryn_jobs_newslettersignup', ['confirmation_key'])


    models = {
        u'aldryn_jobs.jobapplication': {
            'Meta': {'ordering': "['-created']", 'object_name': 'JobApplication'},
            'cover_letter': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '20'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_rejected': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'job_offer': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['aldryn_jobs.JobOffer']"}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '20'}),
            'rejection_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'salutation': ('django.db.models.fields.CharField', [], {'default': "'male'", 'max_length': '20', 'blank': 'True'})
        },
        u'aldryn_jobs.jobapplicationattachment': {
            'Meta': {'object_name': 'JobApplicationAttachment'},
            'application': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'attachments'", 'to': u"orm['aldryn_jobs.JobApplication']"}),
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        u'aldryn_jobs.jobcategory': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'JobCategory'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'supervisors': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'related_name': "'job_offer_categories'", 'blank': 'True', 'to': u"orm['auth.User']"})
        },
        u'aldryn_jobs.jobcategorytranslation': {
            'Meta': {'unique_together': "[['slug', 'language_code'], ('language_code', 'master')]", 'object_name': 'JobCategoryTranslation', 'db_table': "u'aldryn_jobs_jobcategory_translation'"},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language_code': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'master': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'translations'", 'null': 'True', 'to': u"orm['aldryn_jobs.JobCategory']"}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '255', 'blank': 'True'})
        },
        u'aldryn_jobs.joblistplugin': {
            'Meta': {'object_name': 'JobListPlugin', '_ormbases': ['cms.CMSPlugin']},
            u'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'})
        },
        u'aldryn_jobs.jobnewsletterregistrationplugin': {
            'Meta': {'object_name': 'JobNewsletterRegistrationPlugin', '_ormbases': ['cms.CMSPlugin']},
            u'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'mail_to_group': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Group']", 'symmetrical': 'False'})
        },
        u'aldryn_jobs.joboffer': {
            'Meta': {'ordering': "['category__ordering', 'category', '-created']", 'object_name': 'JobOffer'},
            'can_apply': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'category': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'jobs'", 'to': u"orm['aldryn_jobs.JobCategory']"}),
            'content': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.Placeholder']", 'null': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'publication_end': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'publication_start': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'})
        },
        u'aldryn_jobs.joboffertranslation': {
            'Meta': {'unique_together': "[['slug', 'language_code'], ('language_code', 'master')]", 'object_name': 'JobOfferTranslation', 'db_table': "u'aldryn_jobs_joboffer_translation'"},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language_code': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'lead_in': ('djangocms_text_ckeditor.fields.HTMLField', [], {'blank': 'True'}),
            'master': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'translations'", 'null': 'True', 'to': u"orm['aldryn_jobs.JobOffer']"}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '255', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'aldryn_jobs.newslettersignup': {
            'Meta': {'object_name': 'NewsletterSignup'},
            'confirmation_key': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '40'}),
            'default_language': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '32', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_disabled': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_verified': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'recipient': ('django.db.models.fields.EmailField', [], {'unique': 'True', 'max_length': '75'}),
            'signup_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'})
        },
        u'auth.group': {
            'Meta': {'object_name': 'Group'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        u'auth.permission': {
            'Meta': {'ordering': "(u'content_type__app_label', u'content_type__model', u'codename')", 'unique_together': "((u'content_type', u'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['contenttypes.ContentType']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        u'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'related_name': "u'user_set'", 'blank': 'True', 'to': u"orm['auth.Group']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'related_name': "u'user_set'", 'blank': 'True', 'to': u"orm['auth.Permission']"}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'cms.cmsplugin': {
            'Meta': {'object_name': 'CMSPlugin'},
            'changed_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.CMSPlugin']", 'null': 'True', 'blank': 'True'}),
            'placeholder': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.Placeholder']", 'null': 'True'}),
            'plugin_type': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'position': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'cms.placeholder': {
            'Meta': {'object_name': 'Placeholder'},
            'default_width': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slot': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'})
        },
        u'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['aldryn_jobs']


# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.core.exceptions import ImproperlyConfigured
from django.core.urlresolvers import resolve, Resolver404
from django.utils.translation import (
    ugettext_lazy as _,
    get_language_from_request
)

from aldryn_apphooks_config.utils import get_app_instance
from cms.toolbar_base import CMSToolbar
from cms.toolbar_pool import toolbar_pool
from cms.utils.urlutils import admin_reverse

from .cms_appconfig import JobsConfig
from .models import JobOpening


def get_jobopening_from_path(path, language, current_url=None):
    # There is an issue with resolve(path) which is related to django cache
    # (django functools memoize) which uses usual dict and cannot be disabled
    # that leads to a Resolver404 because that cache contains wrong language
    # url resolver. Since request at the moment of calling this function
    # already contains resolver with desired result - we will try to use that
    # In best case this block of code (current_url is None) won't be
    # executed, but if it is - we'll try to get this resolved or will fail
    # with pointing to this place and catch traceback, THE REAL one.
    if current_url is None:
        try:
            current_url = resolve(path)
        except Resolver404:
            raise ImproperlyConfigured(
                "Could not resolve path to obtain current url for"
                " populating cms menu")

    if current_url.url_name == 'job-opening-detail':
        # since identical names are allowed with different namespaces -
        # perform correct lookup.
        job_opening = JobOpening.objects.language(
            language).namespace(current_url.namespace)

        if 'category_slug' in current_url.kwargs:
            category_slug = current_url.kwargs['category_slug']
            job_opening = job_opening.filter(
                category__translations__slug=category_slug,
                category__translations__language_code=language
            )

        if 'job_opening_slug' in current_url.kwargs:
            job_slug = current_url.kwargs['job_opening_slug']
            job_opening = job_opening.translated(language, slug=job_slug)

        if job_opening.count():
            # Let MultipleObjectsReturned propagate if it is raised
            return job_opening.get()

    return None


@toolbar_pool.register
class JobsToolbar(CMSToolbar):

    def get_jobs_config(self):
        try:
            __, config = get_app_instance(self.request)
            if not isinstance(config, JobsConfig):
                # This is not the app_hook you are looking for.
                return None
        except ImproperlyConfigured:
            # There is no app_hook at all.
            return None

        return config

    def populate(self):
        def can(actions, model):
            try:
                # Py2
                basestring = basestring
            except NameError:
                # Py3
                basestring = (str, bytes)

            if isinstance(actions, basestring):
                actions = [actions]
            for action in actions:
                perm = 'aldryn_jobs.%(action)s_%(model)s' % {
                    'action': action, 'model': model
                }
                if not self.request.user.has_perm(perm):
                    return False
            return True

        if self.is_current_app and (can(['add', 'change'], 'jobopening') or
                                    can(['add', 'change'], 'jobsconfig')):
            menu = self.toolbar.get_or_create_menu('jobs-app', _('Jobs'))

            # try to reuse resolver_match instead of doing double work with
            # cache issues, see comments inside of get_jobopening_from_path
            current_url = getattr(self.request, 'resolver_match', None)
            jobsconfig = self.get_jobs_config()
            language = get_language_from_request(self.request, check_path=True)
            job_opening = get_jobopening_from_path(
                self.request.path, language, current_url=current_url
            )

            if jobsconfig and can(['add', 'change'], 'jobsconfig'):
                url = admin_reverse('aldryn_jobs_jobsconfig_change',
                                    args=(jobsconfig.pk, ))
                menu.add_modal_item(_('Configure application'), url)

            if can(['add', 'change'], 'jobcategory'):
                if job_opening and job_opening.category:
                    url = admin_reverse('aldryn_jobs_jobcategory_change',
                        args=(job_opening.category.pk, ))
                    menu.add_modal_item(_('Edit category'), url, active=True)

                base_url = admin_reverse('aldryn_jobs_jobcategory_add')
                url = "{base}?app_config={config}".format(
                    base=base_url, config=jobsconfig.pk if jobsconfig else None)
                menu.add_modal_item(_('Add new category'), url)

            if can(['add', 'change'], 'jobopening'):
                if job_opening:
                    url = admin_reverse(
                        'aldryn_jobs_jobopening_change',
                        args=(job_opening.pk,)
                    )
                    menu.add_modal_item(_('Edit job opening'), url, active=True)
                menu.add_modal_item(
                    _('Add new job opening'),
                    admin_reverse('aldryn_jobs_jobopening_add')
                )



from ..cms_appconfig import JobsConfig
from ..models import JobCategory
from ..forms import JobCategoryAdminForm, JobOpeningAdminForm

from .base import JobsBaseTestCase


class JobCategoryAdminFormTestCase(JobsBaseTestCase):

    def test_form_not_valid_if_app_config_not_selected(self):
        # and it produces validation error instead of 500
        data = {
            'name': self.default_category_values['en']['name'],
            'slug': 'default-category-different-slug',
        }
        form = JobCategoryAdminForm(data)
        self.assertFalse(form.is_valid())
        self.assertIn('app_config', form.errors.keys())

    def test_form_not_valid_no_data_provided_at_all(self):
        # and it produces validation error instead of 500
        data = {}
        form = JobCategoryAdminForm(data)
        self.assertFalse(form.is_valid())
        self.assertIn('app_config', form.errors.keys())
        self.assertIn('name', form.errors.keys())

    def test_form_not_valid_if_only_app_config_was_selected(self):
        # and it produces validation error instead of 500
        data = {'app_config': self.app_config.pk}
        form = JobCategoryAdminForm(data)
        self.assertFalse(form.is_valid())
        self.assertIn('name', form.errors.keys())

    def test_form_not_valid_if_only_name_was_provided(self):
        # and it produces validation error instead of 500
        data = {'name': self.default_category_values['en']['name']}
        form = JobCategoryAdminForm(data)
        self.assertFalse(form.is_valid())
        self.assertIn('app_config', form.errors.keys())

    def test_form_not_valid_if_only_slug_was_provided(self):
        # and it produces validation error instead of 500
        data = {
            'slug': 'default-category-different-slug',
        }
        form = JobCategoryAdminForm(data)
        self.assertFalse(form.is_valid())
        self.assertIn('name', form.errors.keys())
        self.assertIn('app_config', form.errors.keys())

    def test_form_valid_for_same_name_in_different_app_config(self):
        other_config = JobsConfig.objects.create(namespace='other_config')
        data = {
            'app_config': other_config.pk,
            'name': self.default_category_values['en']['name'],
            'slug': 'default-category-different-slug',
        }
        form = JobCategoryAdminForm(data)
        self.assertTrue(form.is_valid())
        new_category = form.save()
        self.assertEqual(new_category.name,
                         data['name'])
        self.assertEqual(new_category.slug,
                         data['slug'])
        self.assertEqual(new_category.app_config, other_config)

    def test_form_valid_for_same_slug_in_different_app_config(self):
        # depends on decision if we will remove uniqueness of slug per language
        other_config = JobsConfig.objects.create(namespace='other_config')
        data = {
            'name': 'different name',
            'slug': self.default_category_values['en']['slug'],
            'app_config': other_config.pk,
        }
        data.update(self.default_category_values['en'])
        form = JobCategoryAdminForm(data)
        self.assertTrue(form.is_valid())
        # test new category values
        new_category = form.save()
        self.assertEqual(new_category.name,
                         data['name'])
        self.assertEqual(new_category.slug,
                         data['slug'])
        self.assertEqual(new_category.app_config, other_config)

    def test_form_is_valid_for_unique_name(self):
        # form should allow unique names
        data = {
            'name': 'Unique name for category',
            'app_config': self.app_config.pk
        }
        form = JobCategoryAdminForm(data)
        self.assertTrue(form.is_valid())

        # test new category values
        new_category = form.save()
        self.assertEqual(new_category.name,
                         data['name'])
        self.assertGreater(len(new_category.slug), 0)
        self.assertEqual(new_category.app_config, self.app_config)

    def test_form_is_valid_for_unique_slug(self):
        # form should allow unique names
        data = {
            'name': 'Unique name for category with slug',
            'slug': 'unique-name-for-category-with-slug',
            'app_config': self.app_config.pk
        }
        form = JobCategoryAdminForm(data)
        self.assertTrue(form.is_valid())
        # test new category values
        new_category = form.save()
        self.assertEqual(new_category.name,
                         data['name'])
        self.assertGreater(len(new_category.slug), 0)
        self.assertEqual(new_category.app_config, self.app_config)


class JobOpeningAdminFormTestCase(JobsBaseTestCase):

    def test_form_not_valid_if_category_not_selected(self):
        # and it produces validation error instead of 500
        self.create_default_job_opening(translated=True)
        # provide same data as for default opening
        data = {
            'title': self.default_job_values['en']['title'],
            'slug': self.default_job_values['en']['slug'],
        }
        form = JobOpeningAdminForm(data)
        self.assertFalse(form.is_valid())
        self.assertIn('category', form.errors.keys())

    def test_form_valid_for_same_name_in_different_category_app_config(self):
        self.create_default_job_opening(translated=True)
        # prepare category with other app config
        other_config = JobsConfig.objects.create(namespace='other_config')
        other_category = JobCategory.objects.create(
            name='Other category', app_config=other_config)

        data = {
            'category': other_category.pk,
            'title': self.default_job_values['en']['title'],
            'slug': 'default-category-different-slug',
        }
        form = JobOpeningAdminForm(data)
        self.assertTrue(form.is_valid())
        new_opening = form.save()
        self.assertEqual(new_opening.title,
                         data['title'])
        self.assertEqual(new_opening.slug,
                         data['slug'])
        self.assertEqual(new_opening.category, other_category)

    def test_form_valid_for_same_slug_in_different_category(self):
        self.create_default_job_opening(translated=True)
        # depends on decision if we will remove uniqueness of slug per language
        other_config = JobsConfig.objects.create(namespace='other_config')
        other_category = JobCategory.objects.create(
            name='Other category', app_config=other_config)

        data = {
            'title': 'different title',
            'slug': self.default_job_values['en']['slug'],
            'category': other_category.pk,
        }
        data.update(self.default_job_values['en'])
        form = JobOpeningAdminForm(data)
        self.assertTrue(form.is_valid())
        # test new category values
        new_opening = form.save()
        self.assertEqual(new_opening.title,
                         data['title'])
        self.assertEqual(new_opening.slug,
                         data['slug'])
        self.assertEqual(new_opening.category, other_category)

    def test_form_is_valid_for_unique_name(self):
        # form should allow unique names
        data = {
            'title': 'Unique title for opening',
            'category': self.default_category.pk
        }
        form = JobOpeningAdminForm(data)
        self.assertTrue(form.is_valid())
        # test new category values
        new_opening = form.save()
        self.assertEqual(new_opening.title,
                         data['title'])
        self.assertGreater(len(new_opening.slug), 0)
        self.assertEqual(new_opening.category, self.default_category)

    def test_form_is_valid_for_unique_slug(self):
        # form should allow unique names
        data = {
            'title': 'Unique title for opening with slug',
            'slug': 'unique-title-for-opening-with-slug',
            'category': self.default_category.pk
        }
        form = JobOpeningAdminForm(data)
        self.assertTrue(form.is_valid())
        # test new category values
        new_opening = form.save()
        self.assertEqual(new_opening.title,
                         data['title'])
        self.assertGreater(len(new_opening.slug), 0)
        self.assertEqual(new_opening.category, self.default_category)



# -*- coding: utf-8 -*-
import sys
from setuptools import setup, find_packages
from aldryn_jobs import __version__

REQUIREMENTS = [
    'aldryn-apphooks-config>=0.1.3',
    'django-appdata>=0.1.4',
    'django-bootstrap3',
    'django-cms>=3.0.12',
    'django-emailit',
    'django-parler',
    'django-standard-form',
    'djangocms-text-ckeditor>= 1.0.10',
    'aldryn-boilerplates',
    'aldryn-common>=0.0.4',
    'aldryn-reversion>=1.0.1',
    'aldryn-translation-tools>=0.2.1',
    # Although we don't actually yet use Aldryn Categories, it has been added
    # because of a migration dependency that sneaked in somehow. In any case we
    # plan to adopt Aldryn Categories for this project in a release in
    # the very near future.
    'aldryn-categories',
    'django-multiupload>=0.3',
    'django-sortedm2m',
    'django-admin-sortable2>=0.5.2',
    'unidecode',
    'lxml',
    'pytz',
    'cssutils',
    'html5lib<0.9999',
]

py26 = sys.version_info >= (2, 6, 5) and sys.version_info < (2, 7, 0)
if py26:
    REQUIREMENTS += [
        'Django>1.5,<1.7',
        'ordereddict',
    ]
else:
    REQUIREMENTS += [
        'Django>=1.6,<1.10',
    ]

CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Framework :: Django :: 1.6',
    'Framework :: Django :: 1.7',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
]

setup(
    name='aldryn-jobs',
    version=__version__,
    description='Publish job openings on your site',
    author='Divio AG',
    author_email='info@divio.ch',
    url='https://github.com/aldryn/aldryn-jobs',
    packages=find_packages(),
    license='LICENSE.txt',
    platforms=['OS Independent'],
    install_requires=REQUIREMENTS,
    classifiers=CLASSIFIERS,
    long_description=open('README.rst').read(),
    include_package_data=True,
    zip_safe=False,
    test_suite="test_settings.run",
)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-02-16 18:49
from __future__ import unicode_literals

from django.apps import apps as django_apps
from django.db import migrations, transaction
from django.db.utils import ProgrammingError, OperationalError


def noop(apps, schema_editor):
    pass


def get_config_count_count(model_class):
    with transaction.atomic():
        count = model_class.objects.count()
    return count


def create_default_newsblog_config(apps, schema_editor):
    # copied and adapted from
    # https://github.com/aldryn/aldryn-newsblog/blob/e447eecd97227613f4c7d960c293794be21b746e/aldryn_newsblog/migrations/0007_default_newsblog_config.py#L20-L70
    import cms.models.fields
    from cms.models import Placeholder
    JobsConfig = apps.get_model('aldryn_jobs', 'JobsConfig')

    # if we try to execute this migration after cms migrations were migrated
    # to latest - we would get an exception because apps.get_model
    # contains cms models in the last known state (which is the dependency
    # migration state). If that is the case we need to import the real model.
    try:
        # to avoid the following error:
        #   django.db.utils.InternalError: current transaction is aborted,
        #   commands ignored until end of transaction block
        # we need to cleanup or avoid that by making transaction atomic.
        count = get_config_count_count(JobsConfig)
    except (ProgrammingError, OperationalError):
        JobsConfig = django_apps.get_model('aldryn_jobs.JobsConfig')
        count = get_config_count_count(JobsConfig)

    if not count == 0:
        return
    # create only if there is no configs because user may already have
    # existing and configured config.
    app_config = JobsConfig(namespace='aldryn_jobs')
    # usually generated in aldryn_apphooks_config.models.AppHookConfig
    # but in migrations we don't have real class with correct parents.
    app_config.type = 'aldryn_jobs.cms_appconfig.JobsConfig'
    # placeholders
    # cms checks if instance.pk is set, and if it isn't cms creates a new
    # placeholder but it does that with real models, and fields on instance
    # are faked models. To prevent that we need to manually set instance pk.
    app_config.pk = 1

    for field in app_config._meta.fields:
        if not field.__class__ == cms.models.fields.PlaceholderField:
            # skip other fields.
            continue
        placeholder_name = field.name
        placeholder_id_name = '{0}_id'.format(placeholder_name)
        placeholder_id = getattr(app_config, placeholder_id_name, None)
        if placeholder_id is not None:
            # do not process if it has a reference to placeholder field.
            continue
        # since there is no placeholder - create it, we cannot use
        # get_or_create because it can get placeholder from other config
        new_placeholder = Placeholder.objects.create(
            slot=placeholder_name)
        setattr(app_config, placeholder_id_name, new_placeholder.pk)
    # after we process all placeholder fields - save config,
    # so that django can pick up them.
    app_config.save()


class Migration(migrations.Migration):

    dependencies = [
        ('aldryn_jobs', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_default_newsblog_config, noop)
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _

from aldryn_jobs.models import JobsConfig
from aldryn_apphooks_config.app_base import CMSConfigApp
from cms.apphook_pool import apphook_pool


class JobsApp(CMSConfigApp):
    name = _('Jobs')
    urls = ['aldryn_jobs.urls']
    app_config = JobsConfig

apphook_pool.register(JobsApp)



# -*- coding: utf-8 -*-
from django.contrib.sitemaps import Sitemap

from ..models import JobCategory, JobOpening


class JobOpeningCategoriesSitemap(Sitemap):
    changefreq = "monthly"
    priority = 0.5

    def items(self):
        return JobCategory.objects.all()


class JobOpeningSitemap(Sitemap):
    changefreq = "monthly"
    priority = 0.5

    def items(self):
        return JobOpening.objects.active()

    def lastmod(self, obj):
        return obj.publication_start
